#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-A.csm"
print ('\n==> Loading geometry from file "'+filename+'"...')
capsProblem = pyCAPS.Problem(problemName = "design_f118",
                             capsFile = filename,
                             outLevel = 1)

# Create an alias to geometry
f118 = capsProblem.geometry

# Build the Wide Body variant

# geometry.despmtr is a Sequence of ValueIn Objects of all DESPMTR defined in the csm file
# Set wide fuselage "fuse:width"
f118.despmtr["fuse:width"].value = 60

# Double the htail:area
htail_area = f118.despmtr["htail:area"].value
f118.despmtr["htail:area"].value = htail_area*2

print ("--> old htail:area = ", htail_area)
print ("--> new htail:area = ", f118.despmtr["htail:area"].value)

# Double the vtail area in an array
vtail = f118.despmtr["vtail"].value
vtail[0] *= 2
f118.despmtr["vtail"].value = vtail

# Build and save geometry
print ('\n==> Bulding and saving Wide Body geometry...')
f118.save("3_f118_Save_Wide.egads")


# Build the Canard variant

# Reset the fuselage
f118.despmtr["fuse:width"].value = 20

htail_area = f118.despmtr["htail:area"].value
wing_area  = f118.despmtr["wing:area"].value

# Swap "wing:area" and "htail:area"
f118.despmtr["htail:area"].value = wing_area
f118.despmtr["wing:area"].value  = htail_area/2

# Make a 2nd vertical tail
vtail = [vtail[:],vtail[:]]                            # create a matrix
f118.cfgpmtr["nrow"].value = 2                         # change the CSM matrix size
vtail[0][4] = -f118.despmtr["fuse:width"].value/2*0.8  # spanwise tail positions
vtail[1][4] =  f118.despmtr["fuse:width"].value/2*0.8
f118.despmtr["vtail"].value = vtail

# Rebuild and save geometry
print ('\n==> Bulding and saving Canard geometry...')
f118.save("3_f118_Save_Canard.egads")

# Display all design parameters
print ('\n==> All design parameters')
for key in f118.despmtr.keys():
    print ('--> {:<12}'.format(key), '=', f118.despmtr[key].value)
