#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-A.csm"
print ('\n==> Loading geometry from file "'+filename+'"...')
capsProblem = pyCAPS.Problem(problemName = "design_f118",
                             capsFile = filename,
                             phaseName = "WideBody",
                             outLevel = 0)

# Create an alias to geometry
f118 = capsProblem.geometry

# Build the Wide Body variant

# Set wide fuselage "fuse:width"
f118.despmtr["fuse:width"].value = 60

# Double the htail:area
htail_area = f118.despmtr["htail:area"].value
f118.despmtr["htail:area"].value = htail_area*2

print ("--> old htail:area = ", htail_area)
print ("--> new htail:area = ", f118.despmtr["htail:area"].value)

# Double the vtail area in an array
vtail = f118.despmtr["vtail"].value
vtail[0] *= 2
f118.despmtr["vtail"].value = vtail

# Build and view the geometry with ESP
print ('\n==> Bulding and viewing Wide Body geometry...')
f118.view()

# Closing the phase marks it as complete and static
capsProblem.closePhase()

# Open a new phase
capsProblem = pyCAPS.Problem(problemName = "design_f118",
                             phaseStart = "WideBody",
                             phaseName = "Canard",
                             outLevel = 0)

# Create an alias to geometry
f118 = capsProblem.geometry

print ('\n==> Bulding and viewing geometry from WideBody phase...')
f118.view()

# Build the Canard variant

# Reset the fuselage
f118.despmtr["fuse:width"].value = 20

htail_area = f118.despmtr["htail:area"].value
wing_area  = f118.despmtr["wing:area"].value

# Swap "wing:area" and "htail:area"
f118.despmtr["htail:area"].value = wing_area
f118.despmtr["wing:area"].value  = htail_area/2

# Make a 2nd vertical tail
vtail = [vtail[:],vtail[:]]                            # create a matrix
f118.cfgpmtr["nrow"].value = 2                         # change the CSM matrix size
vtail[0][4] = -f118.despmtr["fuse:width"].value/2*0.8  # spanwise tail positions
vtail[1][4] =  f118.despmtr["fuse:width"].value/2*0.8
f118.despmtr["vtail"].value = vtail

# Rebuild and view geometry
print ('\n==> Bulding and viewing Canard geometry...')
f118.view()

# Closing the phase marks it as complete and static
capsProblem.closePhase()
