#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_naca",
                             capsFile = filename,
                             outLevel = 1)

# Create xfoil aim
print ("\n==> Creating xfoilAIM")
xfoil = capsProblem.analysis.create(aim = "xfoilAIM",
                                    name = "xfoil")

# Analysis added to capsProblem.analysis Sequence
assert(xfoil == capsProblem.analysis["xfoil"])

# Set Mach number
xfoil.input.Mach = 0.5

# Print the modified mach number
mach = xfoil.input.Mach
print("\n==> Modified Mach =", mach)

# Print the default value of None
print("\n==> Default Alpha =", xfoil.input["Alpha"].value)

# Set Alpha number
xfoil.input.Alpha = 2.5
print("\n==> Modified Alpha =", xfoil.input["Alpha"].value)

# Set list of Alpha
xfoil.input.Alpha = [0.0, 3.0, 5.0, 7.0, 8.0]
print("\n==> Modified Alpha =", xfoil.input["Alpha"].value)

# Unset Alpha back to None
xfoil.input.Alpha = None
print("\n==> Unset Alpha =", xfoil.input["Alpha"].value)
print()
