#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_naca",
                             capsFile = filename,
                             outLevel = 1)

# Create xfoil aim
print ("\n==> Creating xfoilAIM")
xfoil = capsProblem.analysis.create(aim = "xfoilAIM",
                                    name = "xfoil",
                                    autoExec = False)

print ("\n==> Setting analysis values")
# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
xfoil.input.Alpha = [0.0, 3.0, 5.0, 7.0, 8.0]

####### Run xfoil ####################
# Run AIM pre-analysis
print ("\n==> Running preAnalysis")
xfoil.preAnalysis()

# Run xfoil via system call
print ("\n\n==> Running xFoil......")
xfoil.system("xfoil < xfoilInput.txt > Info.out");

# Run AIM post-analysis
print ("\n==> Running postAnalysis")
xfoil.postAnalysis()
######################################

# Retrieve Alpha, Cl and Cd
print ("\n==> Retrieve analysis results")
Alpha = xfoil.output.Alpha
Cl    = xfoil.output.CL
Cd    = xfoil.output.CD

print()
print("--> Alpha =", Alpha)
print("--> Cl    =", Cl)
print("--> Cd    =", Cd)
print()
