#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

# Import matplotlib
from matplotlib import pyplot as plt

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_naca",
                             capsFile = filename,
                             outLevel = 1)

# Create xfoil aim
print ("\n==> Creating xfoilAIM")
xfoil = capsProblem.analysis.create(aim = "xfoilAIM",
                                    name = "xfoil")

# Create an alias to the geometry
naca = capsProblem.geometry

print ("\n==> Setting analysis values")
# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
xfoil.input.Alpha = [-4.0, -2.0, 0.0, 2.0, 4.0, 6.0, 8.0, 10.0, 12.0]

# List of cambers to analyze
Cambers = [0.00, 0.01, 0.04, 0.07]

# Crete the figure with 2 axes and sent the axis labels
fig, ax = plt.subplots(1, 2, figsize=(10,4))
ax[0].set_xlabel("Alpha")
ax[0].set_ylabel("Cl")
ax[1].set_xlabel("Cd")
ax[1].set_ylabel("Cl")

for camber in Cambers:
    # Modify the camber
    naca.despmtr.camber = camber
    
    # Retrieve and plot Alpha, Cl and Cd
    print ("\n==> Retrieve analysis results. camber = ", naca.despmtr.camber)
    Alpha = xfoil.output.Alpha
    Cl = xfoil.output.CL
    Cd = xfoil.output.CD

    ax[0].plot(Alpha, Cl, '-o', label = "Camber = " + str(camber))
    ax[1].plot(Cd, Cl, '-o', label = "Camber = " + str(camber))

# Show the legend on the 2nd axes
ax[1].legend()

# Show the plot
print ("\n==> Plotting analysis results (close plot window to finish Python script")
plt.show()
