#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

def run_xfoil(xfoil):
    # Run AIM pre-analysis
    print ("\n==> Running preAnalysis")
    xfoil.preAnalysis()
        
    # Run xfoil via system call
    print ("\n\n==> Running xFoil......")
    xfoil.system("xfoil < xfoilInput.txt > Info.out"); 
    
    # Run AIM post-analysis
    print ("\n==> Running postAnalysis")
    xfoil.postAnalysis()

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_naca",
                             capsFile = filename,
                             outLevel = 1)

# Create xfoil aim
print ("\n==> Creating xfoilAIM")
xfoil = capsProblem.analysis.create(aim = "xfoilAIM",
                                    name = "xfoil", autoExec = 0)

print("\n1. No Errors ", "-"*80)

# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
print("\n==> Setting alpha sequence")
xfoil.input.Alpha = [0.0, 3.0, 5.0, 7.0, 8.0]

# Run xfoil
run_xfoil(xfoil)

# Retrieve Cl
Cl = xfoil.output.CL
print("\n--> Cl    =", Cl)

print("\n2. DIRTY AnalysisVal Error ", "-"*80)

# Set a new alphas
print("\n==> Setting new alpha sequence")
xfoil.input.Alpha = [1.0, 2.0]

# Try to retrieve Cl without executing pre/postAnalysis
print("\n==> Attempting to get Cl")
try:
    Cl = xfoil.output.CL
    print("\n--> Cl    =", Cl)
except pyCAPS.CAPSError as e:
    print("\n==> CAPSError =", e)

# Run xfoil
run_xfoil(xfoil)

# Retrieve Cl
print("\n==> Attempting to get Cl")
Cl = xfoil.output.CL
print("\n--> Cl    =", Cl)

print("\n3. DIRTY GeometryVal Error ", "-"*80)

# Modify a geometric parameter
print("\n==> Modifying camber")
capsProblem.geometry.despmtr.camber = 0.07

# Try to retrieve Cl without executing pre/postAnalysis
print("\n==> Attempting to get Cl")
try:
    Cl = xfoil.output.CL
    print("\n--> Cl    =", Cl)
except pyCAPS.CAPSError as e:
    print("\n==> CAPSError =", e)

# Run xfoil
run_xfoil(xfoil)

# Retrieve Cl
print("\n==> Attempting to get Cl")
Cl = xfoil.output.CL
print("\n--> Cl    =", Cl)

print("\n4. DIRTY pre- but no postAnalysis Error ", "-"*80)

# Modify mach number
print("\n==> Modifying Mach")
xfoil.input.Mach = 0.3

# Run AIM pre-analysis
print ("\n==> Running preAnalysis but not running postAnalysis")
xfoil.preAnalysis()

# Retrieve Cl
print("\n==> Attempting to get Cl")
try:
    Cl = xfoil.output.CL
    print("\n--> Cl    =", Cl)
except pyCAPS.CAPSError as e:
    print("\n==> CAPSError =", e)

print ("\n\n==> Running xFoil......")
# Run xfoil via system call
xfoil.system("xfoil < xfoilInput.txt > Info.out"); 

# Run AIM post-analysis
print ("\n==> Running postAnalysis")
xfoil.postAnalysis()

# Retrieve Cl
print("\n==> Attempting to get Cl")
Cl = xfoil.output.CL
print("\n--> Cl    =", Cl)

print("\n5. CLEAN Error ", "-"*80)

# Don't modify any analysis or geometry values

try:
    # Run xfoil
    run_xfoil(xfoil)
except pyCAPS.CAPSError as e:
    print("\n==> CAPSError =", e)
