#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "f118-C.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_f118",
                             capsFile = filename,
                             outLevel = 0)

# Create a masstran aim with all the bodies
masstran = capsProblem.analysis.create(aim = "masstranAIM", 
                                       name = "masstran")

# Define material properties
unobtainium = {"density" : 7850}
madeupium   = {"density" : 6890}

# Set the materials
masstran.input.Material = {"Unobtainium": unobtainium,
                           "Madeupium": madeupium}

# Define shell properties
shell_1 = {"propertyType"      : "Shell",
           "material"          : "unobtainium",
           "membraneThickness" : 0.2} 

shell_2 = {"propertyType"      : "Shell",
           "material"          : "madeupium",
           "membraneThickness" : 0.3}

# Associate the shell property with capsGroups defined on the geometry
masstran.input.Property = {"wing:faces" : shell_1, "htail:faces": shell_1, 
                           "fuse:nose"  : shell_1, "fuse:tail"  : shell_1,
                           "vtail:faces": shell_2, "fuse:side"  : shell_2}

# Extract the mass and CG for the f118
Mass = masstran.output.Mass
CG   = masstran.output.CG

print()
print("-->Mass =", Mass)
print("-->CG   =", CG)
