#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

def run_masstran(iter):

    # Load geometry [.csm] file
    filename = "f118-C.csm"
    print ("\n==> Loading geometry from file \""+filename+"\"...")
    capsProblem = pyCAPS.Problem(problemName = "design_f118",
                                 capsFile = filename,
                                 outLevel = 0,
                                 phaseName = "journal",
                                 phaseContinuation = True)
    
    # Create a masstran aim with the wing
    masstran = capsProblem.analysis.create(aim = "masstranAIM", 
                                           name = "masstran",
                                           capsIntent="wing")
    
    # Define shell property
    shell = {"propertyType"      : "Shell",
             "material"          : "Unobtainium",
             "membraneThickness" : 0.2} 

    # Associate the shell property with capsGroups defined on the geometry
    masstran.input.Property = {"wing:faces" : shell}

    masstran.input.Edge_Point_Min = 10
    masstran.input.Edge_Point_Max = 10

    # Set the material
    masstran.input.Material = {"Unobtainium": {"density" : 7850.}}

    print("="*80)
    print("==> Computing mass 1")
    print("-->", masstran.output.Mass)
    if iter == 0: print("Something went wrong!"); return

    # Set the material
    masstran.input.Material = {"Unobtainium": {"density" : 785.0 }}

    print("="*80)
    print("==> Computing mass 2")
    print("-->", masstran.output.Mass)
    if iter == 1: print("Something went wrong!"); return

    # Set the material
    masstran.input.Material = {"Unobtainium": {"density" : 78.50}}

    print("="*80)
    print("==> Computing mass 3")
    print("-->", masstran.output.Mass)

print("\n"+"#"*80)
print("==> First execution")
run_masstran(0)
print("\n"+"#"*80)
print("==> Second execution")
run_masstran(1)
print("\n"+"#"*80)
print("==> Third execution")
run_masstran(2)
print("\n"+"#"*80)
print("==> Fourth execution")
run_masstran(3)