#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "naca.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_mses",
                             capsFile = filename,
                             outLevel = 0)

# Alias the geometry
naca = capsProblem.geometry

print('\n==> Area and Area derivatives...')
print("--> Area         ", naca.outpmtr["Area"].value)
print("--> dArea/dthick ", naca.outpmtr["Area"].deriv("thick"))

# Setup MSES
mses = capsProblem.analysis.create(aim = "msesAIM", name="mses")

# Set flow condition
mses.input.Alpha = 0.0
mses.input.Mach  = 0.5
mses.input.Re = 5e6

# Set meshing parameters
mses.input.GridAlpha = 0
mses.input.Airfoil_Points = 201

# Geometric derivative variables
mses.input.Design_Variable = {"camber":{}, "thick":{}}

# Print the functional and gradients
print('\n==> Drag and Drag derivatives...')
print( "--> CD          =", mses.output["CD"].value )
print( "--> dCD/dAlpha  =", mses.output["CD"].deriv("Alpha") )
print( "--> dCD/dMach   =", mses.output["CD"].deriv("Mach") )
print( "--> dCD/dcamber =", mses.output["CD"].deriv("camber") )
print( "--> dCD/dthick  =", mses.output["CD"].deriv("thick") )

print('\n==> All Drag derivatives...')
print( "--> CD derivs   =", mses.output["CD"].deriv() )
