#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "avlPlaneVanilla.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_PlaneVanilla",
                             capsFile = filename,
                             outLevel = 0)

# Alias the geometry
vanilla = capsProblem.geometry

# view the geometry with ESP
print ("\n==> Viewing Plane Vanilla bodies...")
vanilla.view()

# Create avl aim
print ("\n==> Create avlAIM")
avl = capsProblem.analysis.create(aim = "avlAIM",
                                  name = "avl")

# view the geometry with ESP
print ("\n==> Viewing AVL Plane Vanilla bodies...")
avl.geometry.view()

print ("\n==> Setting analysis values")
avl.input.Alpha = 1.0

# Set meshing parameters for each surface
wing = {"numChord"     : 4,
        "numSpanTotal" : 24}

htail = {"numChord"     : 4,
         "numSpanTotal" : 16}

vtail = {"numChord"     : 4,
         "numSpanTotal" : 10}

# Associate the surface parameters 
# with capsGroups defined on the geometry
avl.input.AVL_Surface = {"Wing" : wing ,
                         "Htail": htail,
                         "Vtail": vtail}

# Print some output values
print ("--> CLtot =", avl.output.CLtot)
print ("--> CDtot =", avl.output.CDtot)
print ("--> CDind =", avl.output.CDind)
print ("--> e     =", avl.output.e)
