#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = "avlPlaneVanilla.csm"
print ("\n==> Loading geometry from file \""+filename+"\"...")
capsProblem = pyCAPS.Problem(problemName = "design_PlaneVanilla",
                             capsFile = filename,
                             outLevel = 0)

# Create avl aim
print ("\n==> Creating avlAIM")
avl = capsProblem.analysis.create(aim = "avlAIM",
                                  name = "avl")

print ("\n==> Setting analysis values")
avl.input.Alpha = 1.0

# Set meshing parameters for each surface
wing = {"numChord"     : 4,
        "numSpanTotal" : 24}

htail = {"numChord"     : 4,
         "numSpanTotal" : 16}

vtail = {"numChord"     : 4,
         "numSpanTotal" : 10}

# Associate the surface parameters with capsGroups defined on the geometry
avl.input.AVL_Surface = {"Wing" : wing ,
                         "Htail": htail,
                         "Vtail": vtail}

# Set control surface parameters
aileronLeft  = {"deflectionAngle" : -25.0}
aileronRight = {"deflectionAngle" :  25.0}
elevator     = {"deflectionAngle" :  5.0}
rudder       = {"deflectionAngle" : -2.0}

avl.input.AVL_Control = {"AileronLeft" : aileronLeft ,
                         "AileronRight": aileronRight,
                         "Elevator"    : elevator    ,
                         "Rudder"      : rudder      }

# Print CL derivatives with old iterface
print ("\n==> Some stability derivatives (old)")
print ("--> CLa  =", avl.output["CLa"].value)  # - Alpha
print ("--> CLb  =", avl.output["CLb"].value)  # - Beta
print ("--> CLp' =", avl.output["CLp'"].value) # - Stability axis Roll rate
print ("--> CLq' =", avl.output["CLq'"].value) # - Stability axis Pitch rate
print ("--> CLr' =", avl.output["CLr'"].value) # - Stability axis Yaw rate

ControlStability = avl.output.ControlStability   # Dictionary of dictionaries
print("--> dCL/dAileronRight =", ControlStability['AileronRight']["CLtot"]) # - Quantities w.r.t. AileronRight
print("--> dCL/dAileronLeft  =", ControlStability['AileronLeft']["CLtot"] ) # - Quantities w.r.t. AileronLeft
print("--> dCL/dElevator     =", ControlStability['Elevator']["CLtot"]    ) # - Quantities w.r.t. Elevator
print("--> dCL/dRudder       =", ControlStability['Rudder']["CLtot"]      ) # - Quantities w.r.t. Rudder

# Print CL derivatives with new interface
print ("\n==> Some stability derivatives (new)")
print ("--> dCL/dAlpha  =", avl.output["CLtot"].deriv("Alpha")) 
print ("--> dCL/dBeta   =", avl.output["CLtot"].deriv("Beta"))  
print ("--> dCL/dp'     =", avl.output["CLtot"].deriv("p'")) 
print ("--> dCL/dq'     =", avl.output["CLtot"].deriv("q'"))  
print ("--> dCL/dr'     =", avl.output["CLtot"].deriv("r'"))  

print ("--> dCL/dAileronRight =", avl.output["CLtot"].deriv("AileronRight")) 
print ("--> dCL/dAileronLeft  =", avl.output["CLtot"].deriv("AileronLeft")) 
print ("--> dCL/dElevator     =", avl.output["CLtot"].deriv("Elevator"))
print ("--> dCL/dRudder       =", avl.output["CLtot"].deriv("Rudder"))
