#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..", "ESP","transport.csm")
capsProblem = pyCAPS.Problem(problemName = "design_Transport",
                             capsFile = filename,
                             outLevel = 0)

# Alias the geometry
transport = capsProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CfdInviscid = 1

# Enable just wing
transport.cfgpmtr.COMP.wing        = 1
transport.cfgpmtr.COMP.fuse        = 0
transport.cfgpmtr.COMP.htail       = 0
transport.cfgpmtr.COMP.vtail       = 0
transport.cfgpmtr.COMP.nacelle     = 0
transport.cfgpmtr.COMP.pylon       = 0
transport.cfgpmtr.COMP.payload     = 0
transport.cfgpmtr.COMP.controls    = 0

# Create AFLR4 AIM
aflr4 = capsProblem.analysis.create(aim = "aflr4AIM",
                                    name = "aflr4")

# Mark capsMesh == Farfield with a Farfield bcType
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Scaling factor to compute AFLR4 'ref_len' parameter via
# ref_len = capsMeshLength * Mesh_Length_Factor
aflr4.input.Mesh_Length_Factor = 5

# Relative scale of maximum spacing bound relative to ref_len
# max_spacing = max_scale * ref_len
aflr4.input.max_scale = 0.1

# Relative scale of minimum spacing bound relative to ref_len
# min_spacing = min_scale * ref_len
aflr4.input.min_scale = 0.01

# Absolute scale of minimum spacing bound for proximity
# abs_min_spacing = abs_min_scale * ref_len
aflr4.input.abs_min_scale = 0.001

# Use mesh length factor to make a series of meshes (not a family)
for Length_Factor in [1, 3, 9]:
    aflr4.input.Mesh_Length_Factor = Length_Factor

    # Run AIM
    aflr4.runAnalysis()

    # View the surface tessellation
    aflr4.geometry.view()
