#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","ESP","transport.csm")
capsProblem = pyCAPS.Problem(problemName = "design_Transport",
                             capsFile = filename,
                             outLevel = 0)

# Alias the geometry
transport = capsProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CfdInviscid = 1

# Enable everything except pylon and payload
transport.cfgpmtr.COMP.wing        = 1
transport.cfgpmtr.COMP.fuse        = 1
transport.cfgpmtr.COMP.htail       = 1
transport.cfgpmtr.COMP.vtail       = 1
transport.cfgpmtr.COMP.nacelle     = 1
transport.cfgpmtr.COMP.pylon       = 0
transport.cfgpmtr.COMP.payload     = 0
transport.cfgpmtr.COMP.controls    = 1

# Create AFLR4 AIM
aflr4 = capsProblem.analysis.create(aim = "aflr4AIM",
                                    name = "aflr4")

# Mark capsMesh == Farfield with a Farfield bcType
# and coarsing components
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"},
                           "leftWing": {"scaleFactor":4},
                           "riteWing": {"scaleFactor":4},
                           "Htail"   : {"scaleFactor":4},
                           "Vtail"   : {"scaleFactor":4},
                           "Nacelle" : {"scaleFactor":5}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Run AIM
aflr4.runAnalysis()

# View the surface tessellation
aflr4.geometry.view()
