#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os module
import os

#------------------------------------------------------------------------------#

useMPI = False

# Load CSM file
filename = os.path.join("..","ESP","transport.csm")
capsProblem = pyCAPS.Problem(problemName = "design_Transport",
                             capsFile = filename,
                             outLevel = 0)

# Alias the geometry
transport = capsProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CfdInviscid = 1

# Enable just wing
transport.cfgpmtr.COMP.wing        = 1
transport.cfgpmtr.COMP.fuse        = 0
transport.cfgpmtr.COMP.htail       = 0
transport.cfgpmtr.COMP.vtail       = 0
transport.cfgpmtr.COMP.nacelle     = 0
transport.cfgpmtr.COMP.pylon       = 0
transport.cfgpmtr.COMP.payload     = 0
transport.cfgpmtr.COMP.controls    = 0

transport.view()

#------------------------------------------------------------------------------#

# Create Cart3D AIM
cart3d = capsProblem.analysis.create(aim = "cart3dAIM")

cart3d.geometry.view()

# Set inputs
cart3d.input.Mach          = 0.8
cart3d.input.alpha         = 1.5
cart3d.input.maxCycles     = 10
cart3d.input.nDiv          = 6
cart3d.input.maxR          = 9
cart3d.input.outer_box     = 8
cart3d.input.y_is_spanwise = True

cart3d.input.Model_X_axis = "-Xb"
cart3d.input.Model_Y_axis = "-Yb"
cart3d.input.Model_Z_axis = "-Zb"

span = transport.outpmtr.wing.span
cart3d.input.Yslices = [0, 0.5*span, span]

# Set inputs added directly to aero.csh
aerocsh = ["set it_fc = 150",
           "set it_ad = 150"]

if useMPI:
    aerocsh.append("set flowCart = mpix_flowCart")
    aerocsh.append("set mpi_prefix = 'mpiexec -n 16'")

cart3d.input.aerocsh = aerocsh

# -----------------------------------------------------------------

# Explicitly Run Cart3D via aero.csh (optional)
cart3d.runAnalysis()

# -----------------------------------------------------------------
# Print outputs
print ("C_A   ", cart3d.output.C_A)
print ("C_Y   ", cart3d.output.C_Y)
print ("C_N   ", cart3d.output.C_N)
print ("C_D   ", cart3d.output.C_D)
print ("C_S   ", cart3d.output.C_S)
print ("C_L   ", cart3d.output.C_L)
print ("C_l   ", cart3d.output.C_l)
print ("C_m   ", cart3d.output.C_m)
print ("C_n   ", cart3d.output.C_n)
print ("C_M_x ", cart3d.output.C_M_x)
print ("C_M_y ", cart3d.output.C_M_y)
print ("C_M_z ", cart3d.output.C_M_z)
