#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load geometry [.csm] file
filename = os.path.join("..","..","data","session03","naca.csm")
print ("\n==> Loading geometry from file \""+filename+"\"...")
myProblem = pyCAPS.Problem(problemName = "design_naca",
                           capsFile = filename,
                           outLevel = 0)

# Alias the geometry
naca = myProblem.geometry

# Create xfoil aim
print ("\n==> Create xfoilAIM")
xfoil = myProblem.analysis.create(aim = "xfoilAIM",
                                  name = "xfoil")

print ("\n==> Setting analysis values")
# Set Mach and Reynolds number
xfoil.input.Mach = 0.5
xfoil.input.Re   = 1.0e6

# Set list of Alpha
xfoil.input.Alpha = [0.0, 1.0, 3.0]

# List of thicknesses to analyze
Thickness = [0.08, 0.10, 0.12, 0.16]

Alpha = []; Cl = []; Cd = []
for thick in Thickness:
    # Modify the thickness
    naca.despmtr.thick = thick

    # Append Alpha, Cl and Cd
    print ("\n==> Retrieve analysis results")
    Alpha.append(xfoil.output.Alpha)
    Cl.append(xfoil.output.CL)
    Cd.append(xfoil.output.CD)

print()
print("--> Thickness =", Thickness)
print("--> Alpha     =", Alpha)
print("--> Cl        =", Cl)
print("--> Cd        =", Cd)
print()
