#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","..","data","EGADS","CFDInviscid_Transport.egads")
myProblem = pyCAPS.Problem(problemName = "workDir_InviscidTransport",
                           capsFile = filename,
                           outLevel = 1)

# Alias the geometry
transport = capsProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CfdInviscid = 1

# Enable just wing
transport.cfgpmtr.COMP.wing        = 1
transport.cfgpmtr.COMP.fuse        = 1
transport.cfgpmtr.COMP.htail       = 1
transport.cfgpmtr.COMP.vtail       = 1
transport.cfgpmtr.COMP.nacelle     = 1
transport.cfgpmtr.COMP.pylon       = 1
transport.cfgpmtr.COMP.payload     = 0
transport.cfgpmtr.COMP.controls    = 0

# Create AFLR4 AIM
aflr4 = myProblem.analysis.create(aim = "aflr4AIM",
                                  name = "aflr4")

# Scale components
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"},
                           "Fuselage": {"scaleFactor":4},
                           "leftWing": {"scaleFactor":4},
                           "riteWing": {"scaleFactor":4},
                           "Htail"   : {"scaleFactor":4},
                           "Vtail"   : {"scaleFactor":4},
                           "Pod"     : {"scaleFactor":1}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Run AIM and generate the surface mesh
aflr4.runAnalysis()

# View the surface tessellation
aflr4.geometry.view()
