#------------------------------------------------------------------------------#

# Import pyCAPS module
import pyCAPS

# Import os
import os

#------------------------------------------------------------------------------#

# Load CSM file
filename = os.path.join("..","..","data","ESP","transport.csm")
myProblem = pyCAPS.Problem(problemName = "design_Transport",
                           capsFile = filename,
                           outLevel = 0)

# Alias the geometry
transport = capsProblem.geometry

# Change to Inviscid CFD view
transport.cfgpmtr.VIEW.Concept     = 0
transport.cfgpmtr.VIEW.CfdInviscid = 1

# Enable just wing
transport.cfgpmtr.COMP.wing        = 1
transport.cfgpmtr.COMP.fuse        = 1
transport.cfgpmtr.COMP.htail       = 1
transport.cfgpmtr.COMP.vtail       = 1
transport.cfgpmtr.COMP.nacelle     = 1
transport.cfgpmtr.COMP.pylon       = 1
transport.cfgpmtr.COMP.payload     = 0
transport.cfgpmtr.COMP.controls    = 0

# Create AFLR4 AIM
aflr4 = myProblem.analysis.create(aim = "aflr4AIM",
                                  name = "aflr4")

# Scaling factor to compute AFLR4 'ref_len' parameter via
# ref_len = capsMeshLength * Mesh_Length_Factor
aflr4.input.Mesh_Length_Factor = 2

# The spacing is derived from the curvature factor divided
# by the curvature.
# Curvature = 1 / Curvature_Radius
# Spacing = curv_factor / Curvature
aflr4.input.curv_factor = 0.2

# Scale components
aflr4.input.Mesh_Sizing = {"Farfield": {"bcType":"Farfield"},
                           "Fuselage": {"scaleFactor":1},
                           "leftWing": {"scaleFactor":2, "edgeWeight":0.0},
                           "riteWing": {"scaleFactor":2, "edgeWeight":0.0},
                           "Htail"   : {"scaleFactor":2, "edgeWeight":0.0},
                           "Vtail"   : {"scaleFactor":2, "edgeWeight":0.0},
                           "Pod"     : {"scaleFactor":1}}

# Farfield growth factor
aflr4.input.ff_cdfr = 1.4

# Run AIM and generate the surface mesh
aflr4.runAnalysis()

# View the surface tessellation
aflr4.geometry.view()

# Print the total element count
print("--> Toal Elements", aflr4.output.NumberOfElement)
